@@ -26,10 +26,10 @@ class Network3Medusa():
                 if first:
                     first = False
                     raw_json=str(interface).replace("\'", "\"")
-                    self.add_file_to_hedera(f"{ raw_json },")
+                    self.add_file_to_hedera(f"[{ raw_json },")
                 elif interface == json_dict['TABLE_interface']['ROW_interface'][-1]:
                     raw_json=str(interface).replace("\'", "\"")
-                    self.append_file_to_hedera(raw_json)
+                    self.append_file_to_hedera(f"{ raw_json }]")
                 else:
                     raw_json=str(interface).replace("\'", "\"")
                     self.append_file_to_hedera(f"{ raw_json },")
